@@ -2,11 +2,6 @@ import sys
 from requests import *  # noqa
 from requests.exceptions import ConnectionError, RequestException
 
-try:
-    from urllib.request import getproxies
-except ImportError:
-    from urllib import getproxies
-
 def new_requests_session(proxies=True, agent=None):
     if agent is None:
         agent = "devpi"
@@ -15,8 +10,6 @@ def new_requests_session(proxies=True, agent=None):
     agent += " (py%s; %s)" % (sys.version.split()[0], sys.platform)
     session = Session()
     session.headers["user-agent"] = agent
-    if proxies:
-        session.proxies = getproxies()
     session.ConnectionError = ConnectionError
     session.RequestException = RequestException
     return session
