@@ -5,19 +5,6 @@ import operator
 
 FunctionType = py.std.types.FunctionType
 
-def propmapping(name, convert=None):
-    if convert is None:
-        def fget(self):
-            return self._mapping.get(name)
-    else:
-        def fget(self):
-            x = self._mapping.get(name)
-            if x is not None:
-                x = convert(x)
-            return x
-    fget.__name__ = name
-    return property(fget)
-
 
 def canraise(Error):
     def wrap(func):
@@ -29,16 +16,18 @@ def canraise(Error):
 def cached_property(f):
     """returns a cached property that is calculated by function f"""
     def get(self):
-        propcache = self.__dict__.setdefault("_property_cache", {})
-        if f in propcache:
-            return propcache[f]
-        x = propcache[f] = f(self)
+        try:
+            return self._property_cache[f]
+        except AttributeError:
+            self._property_cache = {}
+        except KeyError:
+            pass
+        x = self._property_cache[f] = f(self)
         return x
 
     def set(self, val):
         propcache = self.__dict__.setdefault("_property_cache", {})
         propcache[f] = val
-
     return property(get, set)
 
 class CompareMixin(object):
@@ -151,3 +140,9 @@ def ensure_unicode(x):
     if py.builtin._istext(x):
         return x
     return py.builtin._totext(x, "utf8")
+
+def ensure_unicode_keys(somedict, ensure_unicode=ensure_unicode):
+    for key in list(somedict):
+        if not py.builtin._istext(key):
+            val = somedict.pop(key)
+            somedict[py.builtin.text(key, "utf-8")] = val
