@@ -1,14 +1,14 @@
 import sys
+import requests
+import pytest
 from devpi_common.request import new_requests_session
 
 def test_env(monkeypatch):
     monkeypatch.setenv("HTTP_PROXY", "http://this")
     monkeypatch.setenv("HTTPS_PROXY", "http://that")
     session = new_requests_session()
-    assert session.proxies == {"http": "http://this",
-                               "https": "http://that"}
-    session = new_requests_session(proxies=False)
-    assert not session.proxies
+    with pytest.raises(requests.exceptions.ProxyError):
+        session.get("http://example.com")
 
 def test_useragent():
     s = new_requests_session(agent=("hello", "1.2"))
